summaryrefslogtreecommitdiffstats
path: root/kaddressbook/printing/kabentrypainter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/printing/kabentrypainter.cpp')
-rw-r--r--kaddressbook/printing/kabentrypainter.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kaddressbook/printing/kabentrypainter.cpp b/kaddressbook/printing/kabentrypainter.cpp
index c7432d5d..c74e4e41 100644
--- a/kaddressbook/printing/kabentrypainter.cpp
+++ b/kaddressbook/printing/kabentrypainter.cpp
@@ -139,7 +139,7 @@ int KABEntryPainter::hits( const QRectList& list, const TQPoint &p )
int count = 0;
for ( pos = list.begin(); pos != list.end(); ++pos ) {
- if ( (*pos).contains( p ) )
+ if ( (*pos).tqcontains( p ) )
return count;
++count;
@@ -172,7 +172,7 @@ bool KABEntryPainter::printAddressee( const KABC::Addressee &addr,
KABC::Address address;
// this is used to prepare some fields for printing and decide about
- // the layout later:
+ // the tqlayout later:
TQValueList<TQStringList> parts;
TQValueList<QRectList*> contents;
@@ -189,7 +189,7 @@ bool KABEntryPainter::printAddressee( const KABC::Addressee &addr,
painter->setPen( mBackgroundColor );
text = addr.realName();
- // replacement for: api->addressbook()->literalName(entry, text);
+ // tqreplacement for: api->addressbook()->literalName(entry, text);
rect = painter->boundingRect( Ruler1, y, Width, Height,
Qt::AlignVCenter | Qt::AlignLeft, text );
rect.setHeight( (int)( 1.25 * rect.height() ) );
@@ -241,7 +241,7 @@ bool KABEntryPainter::printAddressee( const KABC::Addressee &addr,
if ( !( addr.prefix().isEmpty() ) )
y += fmBody.lineSpacing() / 2;
// fill the parts stringlist, it contains "parts" (printable areas)
// that will be combined to fill the page as effectively as possible:
// Email addresses:
if ( !addr.emails().isEmpty() && mShowEmails ) {
@@ -399,27 +399,27 @@ bool KABEntryPainter::printAddressee( const KABC::Addressee &addr,
line1 = i18n( "Preferred Address" );
}
- line1 += TQString::fromLatin1( ":" );
+ line1 += TQString::tqfromLatin1( ":" );
text = TQString::null;
if ( !address.extended().isEmpty() )
text = address.extended().stripWhiteSpace();
if ( !text.isEmpty() ) {
- line1 = line1 + TQString::fromLatin1( " (" ) + text +
- TQString::fromLatin1( ")" );
+ line1 = line1 + TQString::tqfromLatin1( " (" ) + text +
+ TQString::tqfromLatin1( ")" );
}
line1 = line1.stripWhiteSpace();
line2 = address.street();
if ( !address.postOfficeBox().isEmpty() )
- line2 += TQString::fromLatin1( " - " ) + address.postOfficeBox();
+ line2 += TQString::tqfromLatin1( " - " ) + address.postOfficeBox();
// print address in american style, this will need localisation:
line3 = address.locality() + ( address.region().isEmpty() ?
- TQString::fromLatin1( "" ) : TQString::fromLatin1( ", " ) +
+ TQString::tqfromLatin1( "" ) : TQString::tqfromLatin1( ", " ) +
address.region() ) + ( address.postalCode().isEmpty()
- ? TQString::fromLatin1( "" ) : TQString::fromLatin1( " " )
+ ? TQString::tqfromLatin1( "" ) : TQString::tqfromLatin1( " " )
+ address.postalCode() );
line4 = address.country();
@@ -241,7 +241,7 @@ bool KABEntryPainter::printAddressee( const KABC::Addressee &addr,
if ( !( addr.prefix().isEmpty() ) )
y += fmBody.lineSpacing() / 2;
- // fill the parts stringlist, it contains "parts" (printable areas)
+ // fill the parts stringlist, it tqcontains "parts" (printable areas)
// that will be combined to fill the page as effectively as possible:
// Email addresses: